import { useState } from "react";
import "./index.less";
import Guide from "./components/Guide";
import { useMount } from "../../hook";
import Player from "./components/DPlayer";
import { useParams } from "react-router-dom";
import { getCourseDetailById } from "../../api";
import { ms2Time } from "./util";
import Result from "../../components/Result";
import PlayCircle20Regular from "@ricons/fluent/PlayCircle20Regular";
import DocumentChevronDouble20Regular from "@ricons/fluent/DocumentChevronDouble20Regular";
import { Icon } from "@ricons/utils";
import dayjs from "dayjs";

function CourseDetail() {
  const { id: course_id = "" } = useParams();
  const [toc, setToc] = useState([]);
  const [course, setCourse] = useState<any>({});
  const [view, setView] = useState<any>(null);

  useMount(() => {
    if (!!course_id)
      getCourseDetailById(course_id).then((res: any) => {
        const { data, code } = res;
        if (!data) setToc([]);
        if (code === 10000) {
          const processToc = data?.chapterList.map((item: any) => {
            return {
              title: item.chapter_title,
              level: +item.chapter_level,
              time: ms2Time(+item.media_time),
              icon: !!item.media_url ? (
                <Icon size={20}>
                  <PlayCircle20Regular />
                </Icon>
              ) : null,
              active: false,
              view: (
                <Player
                  video={{ url: item.media_url, pic: item.media_cover_url }}
                />
              ),
            };
          });
          const composeToc = [
            {
              title: "导读",
              level: 1,
              time: "",
            },
            {
              title: "介绍 / 下载",
              level: 2,
              time: "",
              active: true,
              icon: (
                <Icon size={20}>
                  <DocumentChevronDouble20Regular />
                </Icon>
              ),
              view: <Guide mdText={data?.guide.guide_html} />,
            },
            ...processToc,
          ] as any;
          const { course } = data;
          setCourse({
            ...course,
            course_createtime: dayjs(+course.course_createtime).format(
              "YYYY-MM-DD"
            ),
          });
          setToc(composeToc);
          setView(<Guide mdText={data?.guide.guide_value} />);
        } else if (code === 40000) {
          setView(<Result code={403} />);
        }
      });
  });

  const onclickItem = (i: any) => {
    setToc((t: any) =>
      t.map((p: any) => ({ ...p, active: i.title === p.title }))
    );
    setView(i.view ?? <Result code={404} />);
  };

  return (
    <div className="course-detail">
      {toc.length > 0 ? (
        <>
          <aside className="table-of-content">
            <h3>{course.course_title}</h3>
            <div style={{ color: "var(--color-text-3)", fontSize: 13 }}>
              <span>{course.course_createtime}</span>
            </div>
            <div className="toc">
              {toc.map((i: any) => {
                if (i.level === 1) {
                  return (
                    <div className="level-1" key={i.title}>
                      {i.title}
                    </div>
                  );
                } else if (i.level === 2) {
                  return (
                    <div
                      className={`level-2 ${i.active ? "active" : ""}`}
                      key={i.title}
                      onClick={() => onclickItem(i)}
                    >
                      <div className="bs fc">
                        {i.icon}
                        <span style={{ padding: "0 12px 0 6px" }}>
                          {i.title}
                        </span>
                      </div>
                      <span className="time">{i.time}</span>
                    </div>
                  );
                }
              })}
            </div>
          </aside>
          <div className="content" style={{ left: 300 }}>
            {view}
          </div>
        </>
      ) : (
        <Result code={403} />
      )}
    </div>
  );
}

export default CourseDetail;
